.. _api_viewing_geo:

Viewing Geometry
================

.. autoclass:: sasktran2.ViewingGeometry

Viewing Policies
----------------

.. autoclass:: sasktran2.TangentAltitudeSolar

.. autoclass:: sasktran2.GroundViewingSolar
